@@ -25,7 +25,6 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <stdio.h>
-#include <popt.h>
 #include <sys/types.h>
 #include <signal.h>
 #include <sys/socket.h>
@@ -56,6 +55,19 @@ static gboolean authenticate     = FALSE;
 static gboolean no_lock          = FALSE;
 static gboolean monte_carlo_pi   = FALSE;
 static gboolean startnew         = FALSE;
+static gchar **args_remaining    = NULL; 
+
+GOptionEntry options [] = {
+	{ "command", 'c', 0, G_OPTION_ARG_STRING, &send_command, N_("Send the specified protocol command to GDM"), N_("COMMAND") },
+	{ "xnest", 'n', 0, G_OPTION_ARG_NONE, &use_xnest, N_("Xnest mode"), NULL },
+	{ "no-lock", 'l', 0, G_OPTION_ARG_NONE, &no_lock, N_("Do not lock current screen"), NULL },
+	{ "debug", 'd', 0, G_OPTION_ARG_NONE, &debug_in, N_("Debugging output"), NULL },
+	{ "authenticate", 'a', 0, G_OPTION_ARG_NONE, &authenticate, N_("Authenticate before running --command"), NULL },
+	{ "startnew", 's', 0, G_OPTION_ARG_NONE, &startnew, N_("Start new flexible session; do not show popup"), NULL },
+	{ "monte-carlo-pi", 0, 0, G_OPTION_ARG_NONE, &monte_carlo_pi, NULL, NULL },
+	{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &args_remaining, NULL, NULL },
+	{ NULL }
+};
 
 static int
 get_cur_vt (void)
@@ -124,10 +136,9 @@ get_vt_num (char **vec, char *vtpart, int depth)
 	for (i = 0; vec[i] != NULL; i++) {
 		char **rvec;
 		rvec = g_strsplit (vec[i], ",", -1);
-		if (ve_vector_len (rvec) != 3) {
-			g_strfreev (rvec);
+		if (rvec == NULL ||
+		    ve_vector_len (rvec) != 3)
 			continue;
-		}
 
 		if (strcmp (rvec[0], vtpart) == 0) {
 			/* could be nested? */
@@ -166,10 +177,9 @@ create_model (char **vec)
 		char **rvec;
 		int vt;
 		rvec = g_strsplit (vec[i], ",", -1);
-		if (ve_vector_len (rvec) != 3) {
-			g_strfreev (rvec);
+		if (rvec == NULL ||
+		    ve_vector_len (rvec) != 3)
 			continue;
-		}
 
 		vt = get_vt_num (vec, rvec[2], 5);
 
@@ -506,10 +516,9 @@ check_for_users (void)
 		char **rvec;
 		int vt;
 		rvec = g_strsplit (vec[i], ",", -1);
-		if (ve_vector_len (rvec) != 3) {
-			g_strfreev (rvec);
+		if (rvec == NULL ||
+		    ve_vector_len (rvec) != 3)
 			continue;
-		}
 
 		vt = get_vt_num (vec, rvec[2], 5);
 
@@ -687,18 +696,6 @@ calc_pi (void)
 	}
 }
 
-struct poptOption options [] = {
-	{ "command", 'c', POPT_ARG_STRING, &send_command, 0, N_("Send the specified protocol command to GDM"), N_("COMMAND") },
-	{ "xnest", 'n', POPT_ARG_NONE, &use_xnest, 0, N_("Xnest mode"), NULL },
-	{ "no-lock", 'l', POPT_ARG_NONE, &no_lock, 0, N_("Do not lock current screen"), NULL },
-	{ "debug", 'd', POPT_ARG_NONE, &debug_in, 0, N_("Debugging output"), NULL },
-	{ "authenticate", 'a', POPT_ARG_NONE, &authenticate, 0, N_("Authenticate before running --command"), NULL },
-	{ "startnew", 's', POPT_ARG_NONE, &startnew, 0, N_("Start new flexible session; do not show popup"), NULL },
-	{ "monte-carlo-pi", 0, POPT_ARG_NONE, &monte_carlo_pi, 0, NULL, NULL },
-	POPT_AUTOHELP
-	{ NULL, 0, 0, NULL, 0}
-};
-
 
 int
 main (int argc, char *argv[])
@@ -708,18 +705,17 @@ main (int argc, char *argv[])
 	char *version;
 	char *ret;
 	const char *message;
-	poptContext ctx;
-	const char **args;
-	int nextopt;
+	GOptionContext *ctx;
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
 	/* Option parsing */
-
-	ctx = poptGetContext(NULL, argc, (const char**)argv, options, 0);
-	while ((nextopt = poptGetNextOpt(ctx)) > 0 || nextopt == POPT_ERROR_BADOPT);
+	ctx = g_option_context_new("- New gdm login");
+        g_option_context_add_main_entries(ctx, options, _("main options"));
+        g_option_context_parse(ctx, &argc, &argv, NULL);
+        g_option_context_free(ctx);
 
 	if (monte_carlo_pi) {
 		calc_pi ();
@@ -728,30 +724,11 @@ main (int argc, char *argv[])
 
 	gdmcomm_set_debug (debug_in);
 
-	args = poptGetArgs (ctx);
-	if (args != NULL && args[0] != NULL)
-		server = args[0];
+	if (args_remaining != NULL && args_remaining[0] != NULL)
+		server = args_remaining[0];
 
-	if (send_command != NULL) {
-		if ( ! gdmcomm_check (FALSE)) {
-			gdm_common_error ("Error: GDM (GNOME Display Manager) "
-			"is not running.");
-			gdm_common_error ("You might be using a different "
-			"display manager.");
-			return 1;
-		}
-	} else {
-		/*
-		 * The --command argument does not display anything, so avoid
-		 * running gtk_init until it finishes.  Sometimes the
-		 * --command argument is used when there is no display so it
-		 * will fail and cause the program to exit, complaining about
-		 * "no display".
-		 */
-		gtk_init(&argc, &argv);
-		if ( ! gdmcomm_check (TRUE)) {
-			return 1;
-		}
+	if ( ! gdmcomm_check (FALSE)) {
+		return 1;
 	}
 
 	/* Start reading config data in bulk */
@@ -817,22 +794,25 @@ main (int argc, char *argv[])
 	}
 
 	/*
-	 * Now process what gdmflexiserver is more frequently used to
-	 * do, start VT (Virtual Terminal) sesions - at least on
-	 * systems where it is supported.  On systems where it is not
-	 * supporteed VT stands for "Very Tight" and will mess up your
-	 * display if you use it.  Tight!  So do not use it.
+	 * The --command argument does not display anything, so avoid running 
+	 * gtk_init until it finishes.  Sometimes the --command argument is
+	 * used when there is no display so it will fail and cause the 
+	 * program to exit, complaining about "no display".  
 	 *
-	 * I would accept a patch to disable it on such systems, but it
-	 * is easy to avoid not using it as long as your distro does not
-	 * put the menu choice in the application launch button on the
-	 * panel (don't ship the desktop file).
+	 * Now process what gdmflexiserver is more used to do, start a
+	 * VT virtual terminal sesions - at least on systems where it
+	 * works.  On systems where it doesn't work VT stands for
+	 * "Very Tight" and will mess up your display if you try to
+	 * use it.  Tight!  So don't use it.  I'd accept a patch to
+	 * disable it, but its easy to avoid not using it as long
+	 * as your distro doesn't put the menu choice in the 
+	 * application launch button on the panel (don't ship the
+	 * desktop file).
 	 */
+	gtk_init(&argc, &argv);
 
-	/*
-	 * Always attempt to get cookie and authenticate.  On remote
-	 * servers
-	 */
+	/* always attempt to get cookie and authenticate.  On remote
+	servers */
 	auth_cookie = gdmcomm_get_auth_cookie ();
 
 	/* check for other displays/logged in users */
@@ -906,6 +886,8 @@ main (int argc, char *argv[])
 	ret = gdmcomm_call_gdm (command, auth_cookie, version, 5);
 	g_free (command);
 
+	g_strfreev (args_remaining);
+
 	/* At this point we are done using the socket, so close it */
 	gdmcomm_comm_bulk_stop ();
 
