@@ -404,10 +404,10 @@ parse_stock (xmlNodePtr node,
 	  g_free (*translated_text);
 	  *translated_text = g_strdup (_("_Cancel"));
 	}
-      else if (g_ascii_strcasecmp ((char *) prop, "startover") == 0)
+      else if (g_ascii_strcasecmp ((char *) prop, "startagain") == 0)
         {
           g_free (*translated_text);
-          *translated_text = g_strdup (_("_Start Over"));
+          *translated_text = g_strdup (_("_Start Again"));
         }
       else
         {
@@ -499,11 +499,10 @@ parse_gtkbutton (xmlNodePtr node,
 		    GreeterItemInfo *info,
 		    GError **error)
 {
-  char *translated_text;
-  gint translation_score = 1000;
   xmlNodePtr child;
-  int i;
-		
+  char *translated_text  = NULL;
+  gint translation_score = 1000;
+
   child = node->children;
 
   while (child)
@@ -1297,11 +1296,9 @@ parse_label (xmlNodePtr        node,
 {
   xmlNodePtr child;
   int i;
-  char *translated_text;
+  char *translated_text  = NULL;
   gint translation_score = 1000;
   
-  translated_text = NULL;
-
   child = node->children;
   while (child)
     {
@@ -1398,10 +1395,10 @@ parse_listitem (xmlNodePtr        node,
 		GError         **error)
 {
   xmlNodePtr child;
-  char *translated_text = NULL;
-  gint translation_score = 1000;
   xmlChar *prop;
   GreeterItemListItem *li;
+  char *translated_text  = NULL;
+  gint translation_score = 1000;
   
   prop = xmlGetProp (node,(const xmlChar *) "id");
   
@@ -1651,7 +1648,7 @@ parse_items (xmlNodePtr  node,
 		res = parse_list (child, info, error);
 		break;
 	      case GREETER_ITEM_TYPE_BUTTON:
-                res = parse_gtkbutton (child, info, error);
+		res = parse_gtkbutton (child, info, error);
 		break;
 	      default:
 		g_set_error (error,
